@@ -47,7 +47,7 @@ def make_region(coordinates, width: int, resolution: int):
 
 
 class Oracle:
-    def __init__(self, loop_list_path: str, hic_file: str, models_dir: str, norm: str, width: int = 56,chr_list:list=['All']):
+    def __init__(self, loop_list_path: str, hic_file: str, models_dir: str, norm: str, width: int = 56,chr_list : list = None):
         self.__loopList = self.load_loops(loop_list_path)
         self.__hic = hs.HiCFile(hic_file)
         self.__norm = norm
@@ -59,7 +59,7 @@ class Oracle:
         self.__model = tf.keras.models.load_model(self.__modelsDir)
 
     def makeChrList(self,chrList):
-        if chrList == ['All']:
+        if chrList is None:
           return [x.name for x in self.__hic.getChromosomes() if x.name!='All']
         return [str(x) for x in chrList]
 
@@ -98,7 +98,7 @@ class Oracle:
 
           sublist = sublist[sublist['chr1']==chr]
 
-          mzd = self.__hic.getMatrixZoomData(chr, chr, "observed", 'SCALE' , "BP", reso)
+          mzd = self.__hic.getMatrixZoomData(chr, chr, "observed", self.__norm , "BP", reso)
           for index, row in sublist.iterrows():   
             x1,x2,y1,y2 = make_region((row[CHROM_KEY],row[X1_KEY],row[X2_KEY],row[Y1_KEY],row[Y2_KEY]),self.__width-1,reso)
             mat = mzd.getRecordsAsMatrix(x1,x2,y1,y2)
